@@ -8,11 +8,14 @@ get_predictions_logistf <- function(model, fitfram, terms, ...) {
   grp_means <- tapply(
     prdat$predictions,
     lapply(terms, function(i) prdat[[i]]),
-    function(j) mean(j, na.rm = TRUE),
+    mean, na.rm = TRUE,
     simplify = FALSE
   )
 
-  terms_df <- data.frame(expand.grid(attributes(grp_means)$dimnames), stringsAsFactors = FALSE)
+  terms_df <- data.frame(
+    expand.grid(attributes(grp_means)$dimnames),
+    stringsAsFactors = FALSE
+  )
   colnames(terms_df) <- terms
   terms_df <- .convert_numeric_factors(terms_df)
 
