@@ -31,7 +31,7 @@
 
     if (length(weights) != length(x)) {
       # if not, tell user and change function to mean
-      warning("Vector of weights is of different length than `x`. Using `mean` as function for typical value.", call. = FALSE)
+      insight::format_warning("Vector of weights is of different length than `x`. Using `mean` as function for typical value.")
       fun <- "mean"
     }
 
@@ -40,7 +40,7 @@
 
     if (all(weights == 1)) {
       # if not, tell user and change function to mean
-      warning("All weight values are `1`. Using `mean` as function for typical value.", call. = FALSE)
+      insight::format_warning("All weight values are `1`. Using `mean` as function for typical value.")
       fun <- "mean"
     }
   }
@@ -82,8 +82,8 @@
   # that it's not negative for its typical value - else, predict()
   # might fail due to log(<negative number>)...
 
-  if (!is.null(log_terms) && !is.null(predictor) && predictor %in% log_terms) {
-    if (out <= 0) out <- .5
+  if (!is.null(log_terms) && !is.null(predictor) && predictor %in% log_terms && out <= 0) {
+    out <- 0.5
   }
 
   out
